#!/bin/sh
# Licensed Materials - Property of IBM and/or HCL Confidential
# Rational ClearQuest 
# (C) Copyright IBM Corp. 2013, 2016.  All Rights Reserved
# (C) Copyright HCL Technologies Ltd. 2016, 2018.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#
# Run this batch file to copy the Eclipse plugins of the reporting driver from the shared Installation
# Manager directory to a target directory
# Usage:   
#  deployBIRT.sh <no arguments>   ->Deploy default "birt.war" file to default WebSphere Application Server profile, customize the settings
#  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
#  deployBIRT.sh <war_file>  ->Deploy the passed birt war file to default WebSphere Application Server profile, customize the settings
#  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
#  deployBIRT.sh -update <birt_war_name>  ->Update the birt war application to default WebSphere Application Server profile, customize the settings
#  for usage with ClearQuest, clean up old ClearQuest Reporting Driver files and copy new ClearQuest Reporting Driver files.
#  deployBIRT.sh -update <no arguments>  ->Use the default birt_war_name "birt.war" to do update.

usage()
{
   set echo
   echo "Usage:"
   echo "  deployBIRT.sh <no arguments>"
   echo "      Deploy default \"birt.war\" file to default WebSphere Application Server"
   echo "      profile.  Customize the settings for usage with ClearQuest, and copy"
   echo "      the ClearQuest Reporting Driver files."
   echo "  deployBIRT.sh <war_file>"
   echo "      Deploy the passed BIRT WAR file to default WebSphere Application Server"
   echo "      profile.  Customize the settings for usage with ClearQuest, and copy"
   echo "      the ClearQuest Reporting Driver files."
   echo "  deployBIRT.sh -update <birt_war_name>"
   echo "      Update the BIRT WAR application to default WebSphere Application Server"
   echo "      profile.  Customize the settings for usage with ClearQuest, clean up old"
   echo "      ClearQuest Reporting Driver files and copy new ClearQuest Reporting Driver"
   echo "      files."
   echo "  deployBIRT.sh -update <no arguments>"
   echo "      Use the default birt_war_name \"birt.war\" to do update."
   unset echo
   exit 0
}

# Initialize settings used during script processing.
initializeSettings()
{
   # CQ_HOME must be defined to use this script
   if [ -z "${CQ_HOME}" ]; then
      echo "ERROR: The environment variable \"CQ_HOME\" is undefined.  You need to"
      echo "       \"source cq_setup.sh\" or \"source cq_setup.csh\" in order to use this script."
      exit 1
   fi

   # WAS_PROFILE_PATH=/opt/hcl/ccm/clearquest/cqweb/cqwebprofile
   WAS_PROFILE_PATH=$CQ_HOME/cqweb/cqwebprofile
   BIRT_DRIVER_PATH=
   WAR_FILE=
   REPORT_LAUNCHER_PROPERTY=$WAS_PROFILE_PATH/installedApps/dfltCell/RationalClearQuestReportLauncher.ear/CQReportLauncher.war/WEB-INF/classes/reportlauncher.properties
   PERL_PATH=perl
   RESTARTWAS=NO

   if ( ! [ -d "$WAS_PROFILE_PATH" ]); then
      echo "ERROR: ERROR: The WebSphere profile path in \$WAS_PROFILE_PATH is not a directory."
      echo "       \$WAS_PROFILE_PATH=\"$WAS_PROFILE_PATH\""
      echo "       If you deployed the ClearQuest WAS profile under a different name"
      echo "       or location, then edit this script so that \"WAS_PROFILE_PATH\""
      echo "       points to that location."
      exit 1
   fi
}

# Clear settings established by initializeSettings
clearSettings()
{
   unset WAS_PROFILE_PATH
   unset BIRT_DRIVER_PATH
   unset WAR_FILE
   unset BIRT_WAR_HOME
   unset REPORT_LAUNCHER_PROPERTY
   unset PERL_PATH
}

configureWASForJNI()
{
   echo "Calling wsadmin to run script cq_setup.py for configuring JNI report execution."
   $WAS_PROFILE_PATH/bin/wsadmin.sh -lang jython -f cq_setup.py
}

deployBIRT()
{
   if ( ! [ -f "$WAR_FILE" ]); then
      echo "ERROR: The file $WAR_FILE does not exist."
      echo "       \$WAR_FILE=\"$WAR_FILE\""
      echo "       Make sure you provided the correct file name."
      exit 1
   fi

   echo "Calling wsadmin to deploy $WAR_FILE"
   $WAS_PROFILE_PATH/bin/wsadmin.sh -lang jython -f deployBIRT.py $WAR_FILE -wsadmin_classpath ./deployBIRT.jar

   setDefaultBIRTPath

   copyJSP

   if [ "$?" -ne "0" ]; then
      echo "ERROR: \"copyJSP\" failed.  Correct the problem and try again."
      exit 1
   fi

   copyDriverPlugins
}

copyDriverPlugins()
{
   echo "Attempting to clean up certain files, some may not exist, this is expected."
   ./copyDriverPlugins.sh clean $BIRT_DRIVER_PATH

   echo "Calling ./copyDriverPlugins.sh with target path $BIRT_DRIVER_PATH"
   ./copyDriverPlugins.sh $BIRT_DRIVER_PATH

   if [ "$RESTARTWAS" = "YES" ]; then
      restartwas
   fi
}

copyJSP()
{
   BIRT_WAR_HOME=$WAS_PROFILE_PATH/installedApps/dfltCell/birt_war.ear/$WAR_FILE/

   echo "Calling ./copyJSP.sh with target path $BIRT_WAR_HOME"
   ./copyJSP.sh $BIRT_WAR_HOME
}

setDefaultBIRTPath()
{
   local tempPath=$WAS_PROFILE_PATH/installedApps/dfltCell/birt_war.ear/$WAR_FILE/WEB-INF

   if [ -d $tempPath/platform ]; then
      BIRT_DRIVER_PATH=$tempPath/platform/plugins
   else
      BIRT_DRIVER_PATH=$tempPath/lib
   fi
}

doUpdate()
{
   if ( ! [ -f "$WAR_FILE" ]); then
      echo "ERROR: The file $WAR_FILE does not exist."
      echo "       \$WAR_FILE=\"$WAR_FILE\""
      echo "       Make sure you provided the correct file name."
      exit 1
   fi

   setDefaultBIRTPath

   if ( ! [ -f "$REPORT_LAUNCHER_PROPERTY" ]); then
      echo "ERROR: The file $REPORT_LAUNCHER_PROPERTY does not exist."
      echo "       Edit this script to correct the REPORT_LAUNCHER_PROPERTY variable and try again."
      exit 1
   fi

   echo "Start to update reportlauncher.properties file, BIRT JSP and driver plugin."

   $PERL_PATH -pi.bak -e "s/\/birt\/frameset/\/birt\/cqbirt.jsp/g" $REPORT_LAUNCHER_PROPERTY

   if [ $? -eq 0 ]; then
      echo "The file $REPORT_LAUNCHER_PROPERTY is updated successfully."
   else
      echo "ERROR: The file $REPORT_LAUNCHER_PROPERTY update has failed."
      echo "       Edit this script to correct the PERL_PATH variable and try again."
      exit 1
   fi

   RESTARTWAS=YES

   copyJSP

   if [ "$?" -ne "0" ]; then
      echo "ERROR: \"copyJSP\" failed.  Correct the problem and try again."
      exit 1
   fi

   copyDriverPlugins
}

restartwas()
{
   echo "Update is completed. Now please manually restart BIRT WAR and Report Launcher applications under the profile: $WAS_PROFILE_PATH"
   exit 0
}

if [ "$1" = "usage" ]; then usage
   exit 0
fi

# Set local variables and ensures we have everything to deploy BIRT
initializeSettings

if [ $2 ]; then 
    WAR_FILE=$2
else
    WAR_FILE=birt.war
fi

if [ "$1" = "-update" ]; then 
   doUpdate
   exit 0
else
   WAR_FILE=$1
fi

if [ $# -eq 0 ]; then 
   WAR_FILE=birt.war
else
   WAR_FILE=$1
fi

# Create a WAS profile and deploy BIRT into it
deployBIRT

# Next operation configures WebSphere so that it can find required ClearQuest resources for running
# reports that use JNI data sources
configureWASForJNI

exit 0

